@@ -36,7 +36,7 @@
 #'
 #' @examples
 #' \dontrun{
-#' ## This codes can not be run if you don't have encoding system which can en/decode Hangul(ex) CP949, EUC-KR, UTF-8). 
+#' ## This codes can not be run if you don't have encoding system which can en/decode Hangul(ex) CP949, EUC-KR, UTF-8).  
 #' dicpath <- paste(system.file(package="KoNLP"), "/dics/data/kE/dic_user2.txt", sep="")
 #' newdic <- read.table(dicpath, sep="\t", header=FALSE, fileEncoding="UTF-8", stringsAsFactors=FALSE)
 #' mergeUserDic(newdic)
@@ -107,7 +107,7 @@ backupUsrDic <- function(ask=TRUE){
     }
     ret2 <- file.copy(UserDicPath, alteredUserDicPath,overwrite=T)
     if(ret1 && ret2){
-      cat("finidhed backup!\n")  
+      cat("Backup was just finished!\n")  
     }else{
       warning(sprintf("Could not copy %s\n", UserDicPath))
       assign("CopyedUserDic", FALSE, KoNLP:::.KoNLPEnv)
